pub enum Aead {
AeadWithDefaultLengthTag(AeadWithDefaultLengthTag),
AeadWithShortenedTag {
aead_alg: AeadWithDefaultLengthTag,
tag_length: usize,
},
}Expand description
Enumeration of authenticated encryption with additional data algorithms supported.
Variants
AeadWithDefaultLengthTag(AeadWithDefaultLengthTag)
AEAD algorithm with a default length tag
AeadWithShortenedTag
AEAD algorithm with a shortened tag.
Fields

aead_alg: AeadWithDefaultLengthTagAn AEAD algorithm.
Implementations
Sourceimpl Aead
impl Aead
Sourcepub fn is_aead_on_block_cipher(self) -> bool
pub fn is_aead_on_block_cipher(self) -> bool
Check if the Aead algorithm needs a block cipher
Sourcepub fn is_chacha20_poly1305_alg(self) -> bool
pub fn is_chacha20_poly1305_alg(self) -> bool
Check if this AEAD algorithm is the (truncated or not) Chacha20-Poly1305 AEAD algorithm.