Enum psa_crypto::types::key_derivation::InputSecret[][src]

pub enum InputSecret<'a> {
    Input(Input<'a>),
    KeyAgreement {
        alg: RawKeyAgreement,
        private_key: Id,
        peer_key: &'a [u8],
    },
}
Enumeration of supported input data for different input steps

Variants

Input

Regular input of bytes or a key ID

Tuple Fields of Input

0: Input<'a>
KeyAgreement

Output of a key agreement

Fields of KeyAgreement

alg: RawKeyAgreement

Key agreement algorithm to use

private_key: Id

Private key to use in key agreement

peer_key: &'a [u8]

Public key data of peer key to use. Must be in the same format that key_management::import accepts for the public key corresponding to the type of private key.