[−][src]Struct psa_crypto::types::key::Attributes
Native definition of the attributes needed to fully describe a cryptographic key.
Fields
lifetime: LifetimeLifetime of the key
key_type: TypeIntrinsic category and type of the key
bits: usizeSize of the key in bits
policy: PolicyPolicy restricting the permitted usage of the key
Implementations
impl Attributes[src]
pub fn is_exportable(self) -> bool[src]
Check if a key has permission to be exported
pub fn can_export(self) -> Result<()>[src]
Check export in a fallible way
Example
use psa_crypto::types::key::{Attributes, Type, Lifetime, Policy, UsageFlags}; use psa_crypto::types::algorithm::{Algorithm, AsymmetricSignature, Hash}; let mut attributes = Attributes { key_type: Type::RsaKeyPair, bits: 1024, lifetime: Lifetime::Volatile, policy: Policy { usage_flags: UsageFlags { export: false, copy: false, cache: false, encrypt: false, decrypt: false, sign_message: false, verify_message: false, sign_hash: false, verify_hash: false, derive: false, }, permitted_algorithms: Algorithm::AsymmetricSignature(AsymmetricSignature::RsaPkcs1v15Sign { hash_alg: Hash::Sha256.into(), }), }, }; // Can not export because the export flag is set to false. attributes.can_export().unwrap_err();
pub fn is_hash_signable(self) -> bool[src]
Check if a key has permission to sign a message hash
pub fn can_sign_hash(self) -> Result<()>[src]
Check hash signing permission in a fallible way
pub fn is_hash_verifiable(self) -> bool[src]
Check if a key has permission to verify a message hash
pub fn can_verify_hash(self) -> Result<()>[src]
Check hash signing permission in a fallible way
pub fn is_encrypt_permitted(self) -> bool[src]
Check if a key has permissions to encrypt a message
pub fn can_encrypt_message(self) -> Result<()>[src]
Check encrypt permission in a fallible way
pub fn is_decrypt_permitted(self) -> bool[src]
Check if a key has permissions to decrypt a message
pub fn can_decrypt_message(self) -> Result<()>[src]
Check decrypt permission in a fallible way
pub fn is_derivable(self) -> bool[src]
Check if a key has permissions to be derived from
pub fn can_derive_from(self) -> Result<()>[src]
Check derive permission of a fallible way
pub fn is_alg_permitted(self, alg: Algorithm) -> bool[src]
Check if the alg given for a cryptographic operation is permitted to be used with the key
pub fn permits_alg(self, alg: Algorithm) -> Result<()>[src]
Check if alg is permitted in a fallible way
pub fn is_compatible_with_alg(self, alg: Algorithm) -> bool[src]
Check if the alg given for a cryptographic operation is compatible with the type of the key
Example
use psa_crypto::types::key::{Attributes, Type, Lifetime, Policy, UsageFlags}; use psa_crypto::types::algorithm::{Algorithm, AsymmetricSignature, Hash}; let permitted_alg = Algorithm::AsymmetricSignature(AsymmetricSignature::RsaPkcs1v15Sign { hash_alg: Hash::Sha256.into(), }); let alg = Algorithm::AsymmetricSignature(AsymmetricSignature::RsaPkcs1v15Sign { hash_alg: Hash::Sha256.into(), }); let mut attributes = Attributes { key_type: Type::RsaKeyPair, bits: 1024, lifetime: Lifetime::Volatile, policy: Policy { usage_flags: UsageFlags { export: false, copy: false, cache: false, encrypt: false, decrypt: false, sign_message: false, verify_message: false, sign_hash: false, verify_hash: false, derive: false, }, permitted_algorithms: permitted_alg, }, }; assert!(attributes.is_compatible_with_alg(alg)); attributes.key_type = Type::RsaPublicKey; assert!(attributes.is_compatible_with_alg(alg));
pub fn compatible_with_alg(self, alg: Algorithm) -> Result<()>[src]
Check if alg is compatible in a fallible way
pub fn from_key_id(key_id: Id) -> Result<Self>[src]
Gets the attributes for a given key ID
The Id structure can be created with the from_persistent_key_id constructor on Id.
Example
psa_crypto::init().unwrap(); let my_key_id = key_management::generate(attributes, None).unwrap(); //... let key_attributes = Attributes::from_key_id(my_key_id);
pub fn export_key_output_size(self) -> Result<usize>[src]
Sufficient size for a buffer to export the key, if supported
pub fn export_public_key_output_size(self) -> Result<usize>[src]
Sufficient size for a buffer to export the public key, if supported
pub fn sign_output_size(self, alg: AsymmetricSignature) -> Result<usize>[src]
Sufficient buffer size for a signature using the given key, if the key is supported
pub fn asymmetric_encrypt_output_size(
self,
alg: AsymmetricEncryption
) -> Result<usize>[src]
self,
alg: AsymmetricEncryption
) -> Result<usize>
Sufficient buffer size for an encrypted message using the given asymmetric encryption algorithm
pub fn asymmetric_decrypt_output_size(
self,
alg: AsymmetricEncryption
) -> Result<usize>[src]
self,
alg: AsymmetricEncryption
) -> Result<usize>
Sufficient buffer size for a decrypted message using the given asymmetric encryption algorithm
pub fn mac_length(self, mac_alg: Mac) -> Result<usize>[src]
Sufficient buffer size for the MAC of the specified algorithm, if compatible
pub fn aead_encrypt_output_size(
self,
alg: Aead,
plaintext_len: usize
) -> Result<usize>[src]
self,
alg: Aead,
plaintext_len: usize
) -> Result<usize>
Sufficient buffer size for an encrypted message using the given aead algorithm
pub fn aead_decrypt_output_size(
self,
alg: Aead,
ciphertext_len: usize
) -> Result<usize>[src]
self,
alg: Aead,
ciphertext_len: usize
) -> Result<usize>
Sufficient buffer size for an encrypted message using the given aead algorithm
pub fn aead_tag_length(self, alg: Aead) -> Result<usize>[src]
The length of a tag for an AEAD algorithm
pub fn raw_key_agreement_output_size(
self,
alg: RawKeyAgreement
) -> Result<usize>[src]
self,
alg: RawKeyAgreement
) -> Result<usize>
Sufficient buffer size for the resulting shared secret from a raw key agreement